==> 0.0.2.tar.gz: lib/impl/event_streams.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:logger/logger.dart';
import 'package:moyoung_ble_plugin/impl/channel_names.dart';
import 'package:moyoung_ble_plugin/impl/moyang_beans.dart';

class BleEventChannels {
  final Logger _logger = Logger();

  Stream<BleScanEvent> get bleScanEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_BLE_SCAN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.v(event.toString());

      return bleScanEventFromJson(event.toString());
    });
  }

  Stream<int> get connStateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_STATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return event;
    });
  }

  Stream<ConnStepChangeBean> get connStepChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_STEP_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return connStepChangeBeanFromJson(event.toString());
    });
  }

  //余诗霞:start
  Stream<ConnHeartRateBean> get connHeartRateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_HEART_RATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connHeartRateEveStm:" + event.toString());

      return connHeartRateBeanFromJson(event);
    });
  }

  Stream<ConnBloodPressureBean> get connBloodPressureEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BLOOD_PRESSURE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connBloodPressureEveStm:" + event.toString());

      return connBloodPressureBeanFromJson(event);
    });
  }

  Stream<ConnBloodOxygenBean> get connBloodOxygenEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BLOOD_OXYGEN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connBloodOxygenEveStm:" + event.toString());

      return connBloodOxygenBeanFromJson(event);
    });
  }

  Stream<void> get connCameraEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_CAMERA)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connCameraEveStm:" + event.toString());
    });
  }

  Stream<int> get connPhoneEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_PHONE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connPhoneEveStm:" + event.toString());

      return event;
    });
  }

  Stream<int> get connDeviceRssiEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_DEVICE_RSSI)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connDeviceRssiEveStm:" + event.toString());

      return event;
    });
  }
  Stream<Map<dynamic, dynamic>> get connLazyFileTransEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_FILE_TRANS)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyFileTransEveStm:" + event.toString());

      return event;
    });
  }
  Stream<Map<dynamic, dynamic>> get connLazyWFFileTransEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_WF_FILE_TRANS)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyWFFileTransEveStm:" + event.toString());

      return event;
    });
  }
  Stream<ConnEgcBean> get connLazyEgcEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_EGC)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyEgcEveStm:" + event.toString());

      return connEgcBeanFromJson(event);
    });
  }

//以下流是李宝忠的
  Stream<Map<dynamic, dynamic>> get connLazyContactAvatarEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_CONTACT_AVATAR)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyContactAvatarEveStm:" + event.toString());

      return event;
    });
  }

//余诗霞:end

  Stream<String> get connTainStateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_TAIN_STATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<String> get connTempChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_TEMP_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<int> get connContactEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_CONTACT)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<bool> get connBatterySavingEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BATTERY_SAVING)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<String> get connTrainingEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_TRAIN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }
}

==> 0.0.3.tar.gz: lib/impl/event_streams.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:logger/logger.dart';
import 'package:moyoung_ble_plugin/impl/channel_names.dart';
import 'package:moyoung_ble_plugin/impl/moyoung_beans.dart';

class MYEventStreams {
  final Logger _logger = Logger();

  Stream<BleScanBean> get bleScanEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_BLE_SCAN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.v(event.toString());

      return bleScanBeanFromJson(event.toString());
    });
  }

  Stream<int> get connStateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_STATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return event;
    });
  }

  Stream<StepChangeBean> get stepsChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_STEP_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return stepChangeBeanFromJson(event.toString());
    });
  }
  //余诗霞补充
  Stream<DeviceBatteryBean> get deviceBatteryEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_DEVICE_BATTERY)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return deviceBatteryBeanFromJson(event);
    });
  }
  Stream<int> get weatherChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_WEATHER_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return event;
    });
  }
  Stream<StepsCategoryBean> get stepsCategoryEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_STEPS_CATEGORY)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return stepsCategoryBeanFromJson(event);
    });
  }
  Stream<SleepBean> get sleepChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_SLEEP_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return sleepBeanFromJson(event);
    });
  }

  Stream<FirmwareUpgradeBean> get connFirmwareUpgradeEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_FIRMWARE_UPGRADE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());
      return firmwareUpgradeBeanFromJson(event);
    });
  }

  Stream<HeartRateBean> get connHeartRateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_HEART_RATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connHeartRateEveStm:" + event.toString());

      return heartRateBeanFromJson(event);
    });
  }

  Stream<BloodPressureBean> get bloodPressureEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BLOOD_PRESSURE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connBloodPressureEveStm:" + event.toString());

      return bloodPressureBeanFromJson(event);
    });
  }

  Stream<BloodOxygenBean> get connBloodOxygenEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BLOOD_OXYGEN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connBloodOxygenEveStm:" + event.toString());

      return bloodOxygenBeanFromJson(event);
    });
  }

  Stream<String> get cameraEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_CAMERA)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connCameraEveStm:" + event.toString());
      return event;
    });
  }

  Stream<int> get phoneEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_PHONE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connPhoneEveStm:" + event.toString());

      return event;
    });
  }

  Stream<int> get deviceRssiEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_DEVICE_RSSI)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connDeviceRssiEveStm:" + event.toString());

      return event;
    });
  }
  Stream<WatchFaceBgProgressBean> get connLazyFileTransEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_FILE_TRANS)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyFileTransEveStm:" + event.toString());

      return watchFaceBgProgressBeanFromJson(event);
    });
  }
  Stream<FileTransLazyBean> get connLazyWFFileTransEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_WF_FILE_TRANS)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyWFFileTransEveStm:" + event.toString());

      return fileTransLazyBeanFromJson(event);
    });
  }
  Stream<EgcBean> get lazyEcgEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_ECG)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyEcgEveStm:" + event.toString());

      return egcBeanFromJson(event);
    });
  }

//以下流是李宝忠的
  Stream<FileTransLazyBean> get lazyContactAvatarEveStm {
    return const EventChannel(ChannelNames.LAZY_EVE_CHL_CONN_CONTACT_AVATAR)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d("connLazyContactAvatarEveStm:" + event.toString());

      return fileTransLazyBeanFromJson(event);
    });
  }

//余诗霞:end

  Stream<String> get connMovementStateEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_MOVEMENT_STATE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<TempChangeBean> get tempChangeEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_TEMP_CHANGE)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return tempChangeBeanFromJson(event);
    });
  }

  Stream<ContactListenBean> get contactEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_CONTACT)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return contactListenBeanFromJson(event);
    });
  }

  Stream<bool> get batterySavingEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_BATTERY_SAVING)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return event;
    });
  }

  Stream<TrainBean> get trainingEveStm {
    return const EventChannel(ChannelNames.EVE_CHL_CONN_TRAIN)
        .receiveBroadcastStream()
        .map((dynamic event) {
      _logger.d(event.toString());

      return trainBeanFromJson(event);
    });
  }
}
